Skip to contents

Helper function for internal use only

Usage

driveplot_map_color(colorvarnumeric, colorpalette, quocolor, ogdata)

Arguments

colorvarnumeric

An indication of whether the color variable is numeric (TRUE), not numeric (FALSE), or not provided (NULL)

colorpalette

The color palette to use; either a single color (e.g., "red") or one of "viridis", "inferno", "magma", or "plasma".

quocolor

A quosure containing the color variable.

ogdata

The data used to create the domain for the color palette.

Value

The leaflet color palette to be used in driveplot_map().