Skip to contents

Create a vehicle trajectory plot map

Usage

driveplot(
  shareddata,
  lng = NULL,
  lat = NULL,
  x,
  ys,
  colorvar = NULL,
  maplabel = NA,
  colorpalette = "#03F",
  fillOpacity = 1,
  xlabel = NULL,
  ylabels = NULL,
  showlegend = TRUE,
  legendtitle = NULL,
  plottitle = NULL,
  spacing = 0.05
)

Arguments

shareddata

A SharedData object containing observations to be plotted.

lng

The bare (unquoted) column of shareddata containing longitude (only required if shareddata does not have a geometry column).

lat

The bare (unquoted) column of shareddata containing latitude (only required if shareddata does not have a geometry column)

x

The bare (unquoted) column from shareddata to be plotted on the horizontal axis.

ys

A vector or list of bare (unquoted) columns from shareddata to be plotted on the vertical axes of the companion graphs.

colorvar

The bare (unquoted) column in shareddata to which color should be mapped.

maplabel

An optional label for the map points.

colorpalette

The color palette for the plot map; either a single color (e.g., "red") or one of "viridis", "inferno", "magma", or "plasma".

fillOpacity

The opacity of the fill of the map points (0 to 1).

xlabel

The label for the variable on the horizontal axis.

ylabels

A vector or list of labels for the vertical axes of the companion graphs. If provided, it should be the same length as ys.

showlegend

Show the plot legend (TRUE) or not (FALSE).

legendtitle

The title for the plot legend.

plottitle

The title for the plot map.

spacing

A value between 0 and 1 for the space between the companion graphs.

Value

A linked plot map.

Examples

library(crosstalk)
data(drive7)
shared_drive <- SharedData$new(drive7)

driveplot(shareddata = shared_drive,
          x = time_cst,
          ys = c(speed_mph, gyro_heading, gps_heading),
          colorvar = gyro_heading,
          maplabel = time_cst,
          colorpalette = "viridis",
          fillOpacity = 1,
          xlabel = "Time",
          ylabels = c("Speed (mph)", "Gyro Heading (degrees)",
                      "GPS Heading (degrees)"),
          showlegend = TRUE,
          legendtitle = "Gyro Heading")